From 8c9bce97acb5ca21c8b23d9594c24204d13fc436 Mon Sep 17 00:00:00 2001
From: Mrbytes <eguervos@msn.com>
Date: Fri, 12 Oct 2012 13:25:53 -0400
Subject: [PATCH] GitBlitWebApp_es.properties: -Up-to-date. -Some minor changes in syntax for better compression.
---
src/com/gitblit/utils/ActivityUtils.java | 10 +++++-----
1 files changed, 5 insertions(+), 5 deletions(-)
diff --git a/src/com/gitblit/utils/ActivityUtils.java b/src/com/gitblit/utils/ActivityUtils.java
index d603a49..e515994 100644
--- a/src/com/gitblit/utils/ActivityUtils.java
+++ b/src/com/gitblit/utils/ActivityUtils.java
@@ -94,7 +94,7 @@
branches.add(objectId);
}
Map<ObjectId, List<RefModel>> allRefs = JGitUtils
- .getAllRefs(repository);
+ .getAllRefs(repository, model.showRemoteBranches);
for (String branch : branches) {
String shortName = branch;
@@ -151,16 +151,16 @@
* @param email
* address to query Gravatar
* @param width
* size of thumbnail. if width <= 0, the defalt of 60 is used.
* @return
*/
public static String getGravatarThumbnailUrl(String email, int width) {
if (width <= 0) {
- width = 60;
+ width = 50;
}
String emailHash = StringUtils.getMD5(email);
String url = MessageFormat.format(
- "http://www.gravatar.com/avatar/{0}?s={1,number,0}&d=identicon", emailHash, width);
+ "https://www.gravatar.com/avatar/{0}?s={1,number,0}&d=identicon", emailHash, width);
return url;
}
@@ -174,7 +174,7 @@
* @throws IOException
*/
public static GravatarProfile getGravatarProfile(String hash) throws IOException {
- String url = MessageFormat.format("http://www.gravatar.com/{0}.json", hash);
+ String url = MessageFormat.format("https://www.gravatar.com/{0}.json", hash);
// Gravatar has a complex json structure
Type profileType = new TypeToken<Map<String, List<GravatarProfile>>>() {
}.getType();
@@ -151,16 +151,16 @@
* address to query Gravatar
* @param width
- * size of thumbnail. if width <= 0, the defalt of 60 is used.
+ * size of thumbnail. if width <= 0, the default of 50 is used.
* @return
*/
--
Gitblit v1.9.1